# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`dbus`](#dbus): Installs and manages D-Bus.
* [`dbus::config`](#dbusconfig)
* [`dbus::install`](#dbusinstall)
* [`dbus::reload`](#dbusreload)
* [`dbus::service`](#dbusservice)

### Defined types

* [`dbus::session`](#dbussession): Manage per-application session bus configuration.
* [`dbus::system`](#dbussystem): Manage per-application system bus configuration.

## Classes

### <a name="dbus"></a>`dbus`

Installs and manages D-Bus.

* **See also**
  * puppet_defined_types::dbus::session
    * dbus::session
  * puppet_defined_types::dbus::system
    * dbus::system

#### Examples

##### Declaring the class

```puppet
include dbus
```

#### Parameters

The following parameters are available in the `dbus` class:

* [`conf_dir`](#conf_dir)
* [`local_session_conf`](#local_session_conf)
* [`local_system_conf`](#local_system_conf)
* [`package_name`](#package_name)
* [`purge_session_dir`](#purge_session_dir)
* [`purge_system_dir`](#purge_system_dir)
* [`service_name`](#service_name)
* [`service_restart`](#service_restart)
* [`session_conf`](#session_conf)
* [`session_dir`](#session_dir)
* [`system_conf`](#system_conf)
* [`system_dir`](#system_dir)
* [`validate`](#validate)

##### <a name="conf_dir"></a>`conf_dir`

Data type: `Stdlib::Absolutepath`

Top-level configuration directory, usually `/etc/dbus-1`.

##### <a name="local_session_conf"></a>`local_session_conf`

Data type: `Stdlib::Absolutepath`

The configuration file used to override the default
session bus configuration, usually `/etc/dbus-1/session-local.conf`.

##### <a name="local_system_conf"></a>`local_system_conf`

Data type: `Stdlib::Absolutepath`

The configuration file used to override the default
system bus configuration, usually `/etc/dbus-1/system-local.conf`.

##### <a name="package_name"></a>`package_name`

Data type: `String`

The name of the package.

##### <a name="purge_session_dir"></a>`purge_session_dir`

Data type: `Boolean`

Whether to purge any unmanaged session bus
configuration files.

##### <a name="purge_system_dir"></a>`purge_system_dir`

Data type: `Boolean`

Whether to purge any unmanaged system bus
configuration files.

##### <a name="service_name"></a>`service_name`

Data type: `String`

The name of the service.

##### <a name="service_restart"></a>`service_restart`

Data type: `String`

The command used to get `dbus-daemon` to reload its
configuration, which is usually `dbus-send --system --type=method_call
--dest=org.freedesktop.DBus / org.freedesktop.DBus.ReloadConfig`. On
platforms that use systemd, this is what the unit does anyway and so will
rely on that where possible.

##### <a name="session_conf"></a>`session_conf`

Data type: `Stdlib::Absolutepath`

The configuration file containing the default session bus
configuration, usually `/etc/dbus-1/session.conf`.

##### <a name="session_dir"></a>`session_dir`

Data type: `Stdlib::Absolutepath`

The directory used by applications to add additional
session bus configuration, usually `/etc/dbus-1/session.d`.

##### <a name="system_conf"></a>`system_conf`

Data type: `Stdlib::Absolutepath`

The configuration file containing the default system bus
configuration, usually `/etc/dbus-1/system.conf`.

##### <a name="system_dir"></a>`system_dir`

Data type: `Stdlib::Absolutepath`

The directory used by applications to add additional system
bus configuration, usually `/etc/dbus-1/system.d`.

##### <a name="validate"></a>`validate`

Data type: `Boolean`

Whether to validate the XML configuration files prior to
installing them.

### <a name="dbusconfig"></a>`dbus::config`

The dbus::config class.

### <a name="dbusinstall"></a>`dbus::install`

The dbus::install class.

### <a name="dbusreload"></a>`dbus::reload`

The dbus::reload class.

### <a name="dbusservice"></a>`dbus::service`

The dbus::service class.

## Defined types

### <a name="dbussession"></a>`dbus::session`

Manage per-application session bus configuration.

* **See also**
  * puppet_classes::dbus
    * dbus

#### Examples

##### 

```puppet
include dbus
dbus::session { 'example':
  content => file('example/example.conf'),
}
```

#### Parameters

The following parameters are available in the `dbus::session` defined type:

* [`content`](#content)
* [`application`](#application)

##### <a name="content"></a>`content`

Data type: `String`

The contents of the file.

##### <a name="application"></a>`application`

Data type: `String`

Used to construct the filename.

Default value: `$title`

### <a name="dbussystem"></a>`dbus::system`

Manage per-application system bus configuration.

* **See also**
  * puppet_classes::dbus
    * dbus

#### Examples

##### 

```puppet
include dbus
dbus::system { 'example':
  content => file('example/example.conf'),
}
```

#### Parameters

The following parameters are available in the `dbus::system` defined type:

* [`content`](#content)
* [`application`](#application)

##### <a name="content"></a>`content`

Data type: `String`

The contents of the file.

##### <a name="application"></a>`application`

Data type: `String`

Used to construct the filename.

Default value: `$title`

